# XYZ Resource Provider

The xyz Resource Provider lets you manage [xyz](http://example.com) resources.

## Installing

This package is available for several languages/platforms:

### Node.js (JavaScript/TypeScript)

To use from JavaScript or TypeScript in Node.js, install using either `npm`:

```bash
npm install @pulumi/xyz
```

or `yarn`:

```bash
yarn add @pulumi/xyz
```

### Python

To use from Python, install using `pip`:

```bash
pip install pulumi_xyz
```

### Go

To use from Go, use `go get` to grab the latest version of the library:

```bash
go get github.com/pulumi/pulumi-xyz/sdk/go/...
```

### .NET

To use from .NET, install using `dotnet add package`:

```bash
dotnet add package Pulumi.xyz
```

## Configuration

The following configuration points are available for the `xyz` provider:

- `xyz:region` (environment: `XYZ`) - the region in which to deploy resources

## Reference

For detailed reference documentation, please visit [the Pulumi registry](https://www.pulumi.com/registry/packages/xyz/api-docs/).
